.. manila-ui documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to manila-ui's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 2

   contributor/readme
   install/installation
   user/usage
   contributor/contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
